src_mowerplus: Find and sync a copy of the latest MowerPlus database file...

Description Usage Arguments Note Examples

Description

Find and sync a copy of the latest MowerPlus database file from an iOS backup

Usage

1
2
src_mowerplus(backup_id, data_loc = "~/Data",
  ios_backup_dir = platform_ios_backup_dir(), overwrite = TRUE)

Arguments

backup_id

the giant hex string of a folder name; if unspecified will use the most recent backup (if found).

data_loc

where mowtrack.sqlite will be sync'd

ios_backup_dir

where to look for iOS backups (tries to auto-derive the value)

overwrite

nuke ^^ if present (def: TRUE)

Note

You may need to setup permissions to be able to use this method depending on which macOS version you're on.

Examples

 1
 2
 3
 4
 5
 6
 7
 8
 9
10
11
## Not run: 
mow_db <- src_mowerplus("28500cd31b9580aaf5815c695ebd3ea5f7455628")

mow_db

glimpse(tbl(mow_db, "ZMOWER"))

glimpse(tbl(mow_db, "ZACTIVITY"))


## End(Not run)

hrbrmstr/deere documentation built on June 20, 2019, 2:21 p.m.