Description Usage Arguments Note Examples
Find and sync a copy of the latest MowerPlus database file from an iOS backup
1 2 | src_mowerplus(backup_id, data_loc = "~/Data",
ios_backup_dir = platform_ios_backup_dir(), overwrite = TRUE)
|
backup_id |
the giant hex string of a folder name; if unspecified will use the most recent backup (if found). |
data_loc |
where |
ios_backup_dir |
where to look for iOS backups (tries to auto-derive the value) |
overwrite |
nuke ^^ if present (def: |
You may need to setup permissions to be able to use this method depending on which macOS version you're on.
1 2 3 4 5 6 7 8 9 10 11 | ## Not run:
mow_db <- src_mowerplus("28500cd31b9580aaf5815c695ebd3ea5f7455628")
mow_db
glimpse(tbl(mow_db, "ZMOWER"))
glimpse(tbl(mow_db, "ZACTIVITY"))
## End(Not run)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.